#
# spec file for package python-css-parser
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-css-parser
Version:        1.0.10
Release:        2.1
Summary:        CSS related utilities (parsing, serialization, etc) for python
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/ebook-utils/css-parser
Source:         https://github.com/ebook-utils/css-parser/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-chardet
BuildArch:      noarch
%python_subpackages

%description
CSS related utilities (parsing, serialization, etc) for python

A fork of the cssutils project based on version 1.0.2. This fork
includes general bug fixes and extensions specific to editing and
working with ebooks.

The main python source code has been modified so that it will run
without further conversion on both Python >= 2.7 and Python 3.X without
any further modules required. All required modifications are handled
local to each file

%prep
%autosetup -p1 -n css-parser-%{version}

sed -i "1d" src/css_parser/{parse,codec,sac,serialize,scripts/csscapture,_codec2,errorhandler,scripts/cssparse,_codec3,scripts/csscombine,tokenize2,version,encutils/__init__,__init__}.py # Fix non-executable scripts

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v

%files %{python_files}
%license COPYING COPYING.LESSER
%doc README.md
%{python_sitelib}/css_parser
%{python_sitelib}/css_parser-%{version}*-info/

%changelog
* Mon May 26 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.10:
  * Fix selector specificity calculation for pseudo-classes
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.9:
  * replace deprecated use of cgi.parse_header
  * drop python 3.6 support
* Mon Oct  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.8:
  * Replace removed assertEquals with assertEqual
  * Upgrade other unittest asserts for clearer error messages
  * tests: adjust exception string checks for python 3.11
  * tests: fix warning about \( and \o being invalid sequences
  * Fix serialization of unknown rules containing comments
- drop relax_error_msg_check.patch (upstream)
* Tue Jan 25 2022 Matej Cepl <mcepl@suse.com>
- Update to version 1.0.7:
  - Fix incorrect license information in one file from a
    copy/paste
  - Use the badge from GA
  - test: relax assertRaisesMsg to match longer strings
  - Add a two level import from above test
  - Add python 3.10 to the CI matrix
  - version 1.0.7
- Add relax_error_msg_check.patch replacing non-standard assert
  methods with the standard ones (gh#ebook-utils/css-parser#12).
* Sat Nov 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.0.6
  * no changelog provided
- Remove deprecated setup.py tests, use %%pyunittest instead. The
  custom run_tests.py is just a stdlib unittest wrapper.
- Drop disable-online-tests.patch -- The tests handle the offline
  case fine now.
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Mon Jan  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable tests
- Add patch to disable online tests:
  * disable-online-tests.patch
* Sat Jan  5 2019 ecsos@opensuse.org
- Initial version 1.0.4
